{pkgs, ...}: {
  home.packages = with pkgs; [
    watchexec # Run command when any file in current dir changes
    android-tools # adb
    # shellcheck # Check bash scripts for common errors
    sqlite
    scrcpy # Mirror android screen to pc
    cargo
    clippy
    cntr # nix debugger
    conda
    micromamba # a better, faster conda
    devcontainer # development container
    devenv # devbox alternative
    dbeaver-bin
    devbox # dev environments using nix
    distrobox # run commands inside docker containers
    gcc
    gradle
    hexedit
    unstable.zed-editor
    jdk
    julia-bin
    (texlive.combine {
      # for rendering latex in inkscape
      inherit
        (texlive)
        scheme-medium
        standalone
        amsmath
        preview
        # needed for org mode export
        wrapfig
        capt-of
        biblatex
        ;
    })
    matlab # Using nix-matlab overlay defined in flake
    maven
    nodejs
    pkg-config # Often needed to build something
    # pwndbg # improved gdb (debugger)
    python3
    rust-analyzer
    rustc
    rustfmt
    # (pkgs.inkscape-with-extensions.override {
    #   inkscapeExtensions = [ pkgs.inkscape-extensions.textext ];
    # })
    # inkscape-with-extensions
    # inkscape-extensions.textext
    inkscape
    gcolor3 # Color picker
    gimp
    drawio
    audacity

    deploy-rs
    sops
    pandoc # markdown preview
    docker-compose

    ## My scripts
    frajul.deploy-to-pianopi
    frajul.rtklib

    (pkgs.writeShellScriptBin "matlab-rsp" ''
      matlab -desktop -sd "/home/julian/git/uwa-channel-model" -softwareopengl
    '')

    (pkgs.writeShellScriptBin "matlab-paper" ''
      matlab -desktop -sd "/home/julian/dev/phdthesis/Phase B/mainSimulation" -softwareopengl
    '')
    (pkgs.writeShellScriptBin "matlab-robotik" ''
      matlab -desktop -sd "/home/julian/nas-sync/Studium/Vorlesungen-Master/ss24/Robotik2" -softwareopengl
    '')
    (pkgs.writeShellScriptBin "matlab-gram" ''
      export GTK_PATH=/usr/lib/gtk-3.0
      nix shell nixpkgs#gcc11 --command matlab -desktop -sd "/home/julian/dev/matlab-gram" -softwareopengl
    '')
    (pkgs.writeShellScriptBin "expenses-tracker" ''
      java -jar /home/julian/dev/expensestracker/app/build/libs/app.jar
    '')
  ];
}
